@@ -1,7 +1,7 @@
 """
 Checks that Pylint does not complain about foreign key sets on models
 """
-#  pylint: disable=missing-docstring
+#  pylint: disable=missing-docstring consider-using-f-string
 
 from django.db import models
 
@@ -16,6 +16,6 @@ class OtherModel(models.Model):
     elsething = models.OneToOneField(SomeModel, on_delete=models.CASCADE)
 
     def something_doer(self):
-        part_a = '%s - %s' % (self.something.name, self.something.timestamp)
+        part_a = f"{self.something.name} - {self.something.timestamp}"
         part_b = self.elsething.name
         return part_a, part_b
